@@ -2,6 +2,7 @@
 /*
  *  Copyright (C) 2004 Hiroyuki Ikezoe
  *  Copyright (C) 2004 Takuro Ashie
+ *  Copyright (C) 2007 Takashi Nakamoto
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -103,6 +104,7 @@ public:
     String         m_dict_encoding;
     String         m_dict_admin_command;
     String         m_add_word_command;
+    String         m_add_word_command_yomi_option;
 
     bool           m_predict_on_input;
     bool           m_use_direct_key_on_predict;
@@ -116,6 +118,10 @@ public:
     bool           m_show_dict_admin_label;
     bool           m_show_add_word_label;
 
+    bool           m_show_tray_icon;
+
+    bool           m_use_custom_lookup_window;
+
     String         m_preedit_style;
     unsigned int   m_preedit_fg_color;
     unsigned int   m_preedit_bg_color;
@@ -130,8 +136,6 @@ public:
     Key2KanaTable *m_custom_kana_table;
     Key2KanaTable *m_custom_nicola_table;
 
-    String         m_kana_layout_ro_key;
-
     /* for key bindings */
     std::vector<Action> m_actions;
 };
