@@ -2,6 +2,7 @@
 /*
  *  Copyright (C) 2004 Hiroyuki Ikezoe
  *  Copyright (C) 2004 Takuro Ashie
+ *  Copyright (C) 2006 - 2007 Takashi Nakamoto
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,6 +34,8 @@
 #include <scim.h>
 #include "scim_anthy_preedit.h"
 #include "scim_anthy_key2kana_table.h"
+#include "scim_anthy_diction.h"
+#include "scim_anthy_const.h"
 
 using namespace scim;
 using namespace scim_anthy;
@@ -41,13 +44,6 @@ class AnthyFactory;
 
 namespace scim_anthy {
 
-typedef enum {
-    SCIM_ANTHY_CONVERSION_MULTI_SEGMENT,
-    SCIM_ANTHY_CONVERSION_SINGLE_SEGMENT,
-    SCIM_ANTHY_CONVERSION_MULTI_SEGMENT_IMMEDIATE,
-    SCIM_ANTHY_CONVERSION_SINGLE_SEGMENT_IMMEDIATE,
-} ConversionMode;
-
 typedef void (*timeout_func) (void *data);
 typedef void (*delete_func)  (void *data);
 
@@ -110,6 +106,22 @@ public:
 
     virtual void reload_config                (const ConfigPointer &config);
 
+protected:
+    /* signal activation functions */
+    void show_aux_string_advanced             (void);
+    void hide_aux_string_advanced             (void);
+    void update_aux_string_advanced           (const WideString &str,
+                                               const AttributeList &attrs
+                                               = AttributeList());
+
+    void show_lookup_table_advanced           (void);
+    void hide_lookup_table_advanced           (void);
+    void update_lookup_table_advanced         (const LookupTable &table);
+
+    void show_note                            (void);
+    void hide_note                            (void);
+    void update_note                          (const WideString &str);
+
 public:
     /* actions */
     bool   action_do_nothing                  (void);
@@ -215,7 +227,6 @@ private:
 
     /* utility */
     void   set_preedition                     (void);
-    void   set_aux_string                     (void);
     void   set_lookup_table                   (void);
     void   unset_lookup_table                 (void);
     void   install_properties                 (void);
@@ -253,12 +264,18 @@ private:
     bool                  m_lookup_table_visible;
     unsigned int          m_n_conv_key_pressed;
 
+    /* for diction */
+    AnthyDictionService   m_diction_service;
+
     /* for toggling latin and wide latin */
     InputMode             m_prev_input_mode;
 
     /* for toolbar */
     PropertyList          m_properties;
 
+    /* for tray icon */
+    PropertyList          m_tray_properties;
+
     /*  */
     ConversionMode        m_conv_mode;
 
