@@ -19,7 +19,6 @@
  */
 
 #define SCIM_ANTHY_USE_GTK
-#include <string.h>
 #include <scim.h>
 #include "scim_anthy_prefs.h"
 #include "scim_anthy_intl.h"
@@ -147,7 +146,7 @@ BoolConfigData config_bool_common [] =
         SCIM_ANTHY_CONFIG_SHOW_CONVERSION_MODE_LABEL,
         SCIM_ANTHY_CONFIG_SHOW_CONVERSION_MODE_LABEL_DEFAULT,
         SCIM_ANTHY_CONFIG_SHOW_CONVERSION_MODE_LABEL_DEFAULT,
-        N_("Show _conversion mode label"),
+        N_("Show _conversion method label"),
         NULL,
         NULL,
         NULL,
@@ -213,6 +212,33 @@ BoolConfigData config_bool_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_USE_CUSTOM_LOOKUP_WINDOW,
+        SCIM_ANTHY_CONFIG_USE_CUSTOM_LOOKUP_WINDOW_DEFAULT,
+        SCIM_ANTHY_CONFIG_USE_CUSTOM_LOOKUP_WINDOW_DEFAULT,
+        N_("Use the scim-anthy's custom lookup _window instead of SCIM's one"),
+        NULL,
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_ANTHY_CONFIG_ENABLE_DICTION,
+        SCIM_ANTHY_CONFIG_ENABLE_DICTION_DEFAULT,
+        SCIM_ANTHY_CONFIG_ENABLE_DICTION_DEFAULT,
+        N_("Show _diction of candidates"),
+        NULL,
+        NULL,
+        NULL,
+    }, 
+    {
+        SCIM_ANTHY_CONFIG_SHOW_TRAY_ICON,
+        SCIM_ANTHY_CONFIG_SHOW_TRAY_ICON_DEFAULT,
+        SCIM_ANTHY_CONFIG_SHOW_TRAY_ICON_DEFAULT,
+        N_("Show _tray icon"),
+        NULL,
+        NULL,
+        NULL,
+    },
     {
         NULL,
         "",
@@ -303,7 +329,7 @@ StringConfigData config_string_common [] =
         SCIM_ANTHY_CONFIG_CONVERSION_MODE,
         SCIM_ANTHY_CONFIG_CONVERSION_MODE_DEFAULT,
         SCIM_ANTHY_CONFIG_CONVERSION_MODE_DEFAULT,
-        N_("_Conversion mode: "),
+        N_("_Conversion method: "),
         NULL,
         NULL,
         NULL,
@@ -455,6 +481,16 @@ StringConfigData config_string_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_YOMI_OPTION,
+        SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_YOMI_OPTION_DEFAULT,
+        SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_YOMI_OPTION_DEFAULT,
+        N_("\"_Yomi\" option for \"Add word\" command:"),
+        NULL,
+        NULL,
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_PREEDIT_STYLE,
         SCIM_ANTHY_CONFIG_PREEDIT_STYLE_DEFAULT,
@@ -782,9 +818,9 @@ StringConfigData config_keyboards_caret [] =
         SCIM_ANTHY_CONFIG_MOVE_CARET_FORWARD_KEY,
         SCIM_ANTHY_CONFIG_MOVE_CARET_FORWARD_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_MOVE_CARET_FORWARD_KEY_DEFAULT,
-        N_("Move forward"),
-        N_("Select move caret forward keys"),
-        N_("The key events to move the caret forward. "),
+        N_("Move to forward"),
+        N_("Select move caret to forward keys"),
+        N_("The key events to move the caret to forward. "),
         NULL,
         false,
     },
@@ -792,9 +828,9 @@ StringConfigData config_keyboards_caret [] =
         SCIM_ANTHY_CONFIG_MOVE_CARET_BACKWARD_KEY,
         SCIM_ANTHY_CONFIG_MOVE_CARET_BACKWARD_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_MOVE_CARET_BACKWARD_KEY_DEFAULT,
-        N_("Move backward"),
-        N_("Select move caret backward keys"),
-        N_("The key events to move the caret backward. "),
+        N_("Move to backward"),
+        N_("Select move caret to backward keys"),
+        N_("The key events to move the caret to backward. "),
         NULL,
         false,
     },
@@ -1098,8 +1134,8 @@ StringConfigData config_keyboards_converting [] =
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_FORWARD_KEY,
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_FORWARD_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_FORWARD_KEY_DEFAULT,
-        N_("Convert character type forward"),
-        N_("Select keys to convert character type forward"),
+        N_("Convert character type to forward"),
+        N_("Select keys to convert character type to forward"),
         N_("Rotate character type forward."),
         NULL,
         false,
@@ -1108,8 +1144,8 @@ StringConfigData config_keyboards_converting [] =
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_BACKWARD_KEY,
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_BACKWARD_KEY_DEFAULT,
         SCIM_ANTHY_CONFIG_CONV_CHAR_TYPE_BACKWARD_KEY_DEFAULT,
-        N_("Convert character type backward"),
-        N_("Select keys to convert character type backward"),
+        N_("Convert character type to backward"),
+        N_("Select keys to convert character type to backward"),
         N_("Rotate character type backward."),
         NULL,
         false,
