@@ -27,7 +27,6 @@
   #include <config.h>
 #endif
 
-#include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
@@ -44,7 +43,7 @@
 #include "scim_anthy_setup_romaji.h"
 #include "scim_anthy_setup_kana.h"
 #include "scim_anthy_utils.h"
-#include "scim_anthy_color_button.h"
+#include "scim_color_button.h"
 
 using namespace scim;
 using namespace scim_anthy;
@@ -276,9 +275,9 @@ static ComboConfigCandidate behavior_on_focus_out[] =
 
 static ComboConfigCandidate dict_encoding[] =
 {
-    {N_("UTF-8"),     "UTF-8"},
     {N_("EUC-JP"),    "EUC-JP"},
     {N_("EUC-JP-MS"), "EUC-JP-MS"},
+    {N_("UTF-8"),     "UTF-8"},
     {NULL, NULL},
 };
 
@@ -332,8 +331,11 @@ static void     on_choose_keys_button_clicked     (GtkWidget        *button,
                                                    gpointer          data);
 static void     on_dict_launch_button_clicked     (GtkButton        *button,
                                                    gpointer          user_data);
-static void     on_color_button_changed           (ScimAnthyColorButton  *button,
-                                                   gpointer               user_data);
+static void     on_use_custom_lookup_window_toggled
+                                                  (GtkToggleButton  *button,
+                                                   gpointer          user_data);
+static void     on_color_button_changed           (ScimColorButton  *button,
+                                                   gpointer          user_data);
 
 
 static StringConfigData *
@@ -601,7 +603,7 @@ create_color_button (const char *config_key)
         gtk_widget_show (label);
     }
 
-    entry->widget = scim_anthy_color_button_new ();
+    entry->widget = scim_color_button_new ();
     gtk_widget_set_size_request (GTK_WIDGET (entry->widget), 32, 24);
     g_signal_connect (G_OBJECT (entry->widget), "color-changed",
                       G_CALLBACK (on_color_button_changed),
@@ -1040,7 +1042,7 @@ create_dict_page (void)
     GtkWidget *table, *button;
     StringConfigData *entry;
 
-    table = gtk_table_new (3, 3, FALSE);
+    table = gtk_table_new (4, 4, FALSE);
     gtk_widget_show (table);
 
     // encoding of dictionary
@@ -1060,7 +1062,7 @@ create_dict_page (void)
                       (GtkAttachOptions) 0, 4, 4);
     g_signal_connect (G_OBJECT (button), "clicked",
                       G_CALLBACK (on_dict_launch_button_clicked), entry);
-    gtk_widget_show (button);
+    //gtk_widget_show (button);
 
     // add word command
     create_entry (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND,
@@ -1074,7 +1076,12 @@ create_dict_page (void)
                       (GtkAttachOptions) 0, 4, 4);
     g_signal_connect (G_OBJECT (button), "clicked",
                       G_CALLBACK (on_dict_launch_button_clicked), entry);
-    gtk_widget_show (button);
+    //gtk_widget_show (button);
+
+    // add yomi option
+    create_entry (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_YOMI_OPTION,
+                  GTK_TABLE(table), 3);
+    entry = find_string_config_entry (SCIM_ANTHY_CONFIG_ADD_WORD_COMMAND_YOMI_OPTION);
 
     return table;
 }
@@ -1082,11 +1089,31 @@ create_dict_page (void)
 static GtkWidget *
 create_candidates_window_page (void)
 {
-    GtkWidget *vbox, *widget, *table;
+    GtkWidget *vbox, *widget, *widget2, *table, *alignment;
 
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
+    /* use custom lookup window */
+    widget = create_check_button (SCIM_ANTHY_CONFIG_USE_CUSTOM_LOOKUP_WINDOW);
+    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
+
+    /* show diction */
+    alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
+    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 24, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), alignment, FALSE, FALSE, 2);
+    gtk_widget_show (alignment);
+
+    widget2 = create_check_button (SCIM_ANTHY_CONFIG_ENABLE_DICTION);
+    gtk_container_add (GTK_CONTAINER (alignment), widget2);
+    gtk_widget_set_sensitive (
+        widget2,
+        SCIM_ANTHY_CONFIG_USE_CUSTOM_LOOKUP_WINDOW_DEFAULT);
+
+    g_signal_connect (G_OBJECT (widget), "toggled",
+                      G_CALLBACK (on_use_custom_lookup_window_toggled),
+                      widget2);
+
     /* show candidates label */
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_CANDIDATES_LABEL);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
@@ -1113,11 +1140,15 @@ create_candidates_window_page (void)
 static GtkWidget *
 create_toolbar_page (void)
 {
-    GtkWidget *vbox, *hbox, *label, *widget;
+    GtkWidget *vbox, /* *hbox, *label,*/ *widget;
 
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
 
+    /* tray icon */
+    widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_TRAY_ICON);
+    gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
+
     /* show/hide toolbar label */
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_INPUT_MODE_LABEL);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
@@ -1141,6 +1172,7 @@ create_toolbar_page (void)
                       NULL);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 2);
 
+#if 0
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 2);
     gtk_widget_show (hbox);
@@ -1154,6 +1186,7 @@ create_toolbar_page (void)
     gtk_widget_show (label);
     widget = create_check_button (SCIM_ANTHY_CONFIG_SHOW_ADD_WORD_LABEL);
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+#endif
 
     // set initial state
     on_dict_menu_label_toggled (GTK_TOGGLE_BUTTON (widget), NULL);
@@ -1162,7 +1195,7 @@ create_toolbar_page (void)
 }
 
 static GtkWidget *
-create_appearance_page (void)
+create_colors_page (void)
 {
     GtkWidget *vbox, *table, *omenu, *widget, *hbox; 
 
@@ -1332,13 +1365,13 @@ create_setup_window (void)
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
-        // Create the appearance  page.
-        page = create_appearance_page ();
-        label = gtk_label_new (_("Appearance"));
+        // Create the colors page.
+        page = create_colors_page ();
+        label = gtk_label_new (_("Colors"));
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
-        // Create the appearance  page.
+        // Create the about page.
         page = create_about_page ();
         label = gtk_label_new (_("About"));
         gtk_widget_show (label);
@@ -1504,8 +1537,8 @@ setup_widget_value (void)
     for (unsigned int i = 0; config_color_common[i].fg_key; i++) {
         ColorConfigData &entry = config_color_common[i];
         if (entry.widget) {
-            scim_anthy_color_button_set_colors (SCIM_ANTHY_COLOR_BUTTON (entry.widget),
-                                                entry.fg_value, entry.bg_value);
+            scim_color_button_set_colors (SCIM_COLOR_BUTTON (entry.widget),
+                                          entry.fg_value, entry.bg_value);
         }
     }
 
@@ -1524,26 +1557,6 @@ setup_widget_value (void)
     setup_key_theme_menu (GTK_OPTION_MENU (__widget_key_theme_menu));
 }
 
-bool operator < (const StyleFile &left, const StyleFile &right)
-{
-    if (const_cast<StyleFile&>(left).get_title() <
-        const_cast<StyleFile&>(right).get_title())
-    {
-        return true;
-    }
-    return false;
-}
-
-bool operator > (const StyleFile &left, const StyleFile &right)
-{
-    if (const_cast<StyleFile&>(left).get_title() >
-        const_cast<StyleFile&>(right).get_title())
-    {
-        return true;
-    }
-    return false;
-}
-
 static void
 load_style_files (const char *dirname)
 {
@@ -1575,7 +1588,6 @@ load_style_files (const char *dirname)
         }
         g_dir_close (dir);
     }
-    std::sort(__style_list.begin(), __style_list.end());
 }
 
 static void
@@ -2103,13 +2115,22 @@ on_dict_launch_button_clicked (GtkButton *button, gpointer user_data)
 }
 
 static void
-on_color_button_changed (ScimAnthyColorButton *button,
+on_use_custom_lookup_window_toggled (GtkToggleButton *toggle_button,
+                                     gpointer user_data)
+{
+    GtkWidget *widget = GTK_WIDGET (user_data);
+    gboolean active = gtk_toggle_button_get_active (toggle_button);
+    gtk_widget_set_sensitive (widget, active);
+}
+
+static void
+on_color_button_changed (ScimColorButton *button,
                          gpointer         user_data)
 {
     ColorConfigData *entry = static_cast <ColorConfigData*> (user_data);
 
     if (entry->widget) {
-        scim_anthy_color_button_get_colors (button, &entry->fg_value, &entry->bg_value);
+        scim_color_button_get_colors (button, &entry->fg_value, &entry->bg_value);
         entry->changed = true;
         __config_changed = true;
     }
